@@ -15,7 +15,7 @@ cargo install -f wasm-bindgen-cli --version 0.2.69
 Then build the code and generate wasm bindings
 ```sh
 cargo build --example split-chart --target wasm32-unknown-unknown
-wasm-bindgen ../target/wasm32-unknown-unknown/debug/examples/split-chart.wasm --out-dir ./examples/js --target web
+wasm-bindgen ./target/wasm32-unknown-unknown/debug/examples/split-chart.wasm --out-dir ./examples/js --target web
 ```
 
 Then, use host the folder examples with a http server
@@ -31,8 +31,8 @@ extern crate iced;
 extern crate plotters;
 
 use iced::{
-    executor, Align, Application, Clipboard, Column, Command, Container, Element, Font, Length,
-    Settings, Subscription,
+    executor, Align, Application, Clipboard, Column, Command, Container, Element, Length, Settings,
+    Subscription,
 };
 use plotters::{coord::Shift, prelude::*};
 use plotters_backend::DrawingBackend;
@@ -48,6 +48,7 @@ fn main() {
     .unwrap();
 }
 
+#[allow(unused)]
 #[derive(Debug)]
 enum Message {
     Tick,
