@@ -5,10 +5,11 @@
 // License: MIT
 
 #[derive(Debug)]
-/// Indicates that some error occured within the Iced backend
+/// Indicates that some error occurred within the Iced backend
 pub enum Error {}
 
 impl std::fmt::Display for Error {
+    #[inline]
     fn fmt(&self, fmt: &mut std::fmt::Formatter) -> std::fmt::Result {
         write!(fmt, "{:?}", self)
     }
