@@ -50,12 +50,14 @@
    ```
    See the [examples](https://github.com/Joylei/plotters-iced/tree/master/examples) for more details.
 */
+#![warn(missing_docs)]
 
 pub extern crate plotters_backend;
 mod chart;
 mod error;
 #[cfg(not(target_arch = "wasm32"))]
 mod native;
+mod utils;
 #[cfg(target_arch = "wasm32")]
 mod web;
 
@@ -72,3 +74,14 @@ pub use web::ChartWidget;
 pub use plotters::{chart::ChartBuilder, drawing::DrawingArea};
 #[doc(no_inline)]
 pub use plotters_backend::DrawingBackend;
+
+impl<'a, Message, C> From<C> for ChartWidget<Message, C>
+where
+    Message: 'static,
+    C: Chart<Message>,
+{
+    #[inline]
+    fn from(chart: C) -> ChartWidget<Message, C> {
+        ChartWidget::new(chart)
+    }
+}
