@@ -12,9 +12,11 @@ use iced_native::{event, mouse::Interaction, Font, Point, Rectangle, Vector};
 use plotters::prelude::DrawingArea;
 use plotters_backend::{FontFamily, FontStyle};
 
-pub type ChartWidget<'a, Message, C> = super::native::ChartWidget<'a, Message, C>;
+/// Chart container, turns [`Chart`]s to [`Widget`]s
+pub type ChartWidget<Message, C> = super::native::ChartWidget<Message, C>;
 
 impl<B: Backend + backend::Text> ChartRenderer for Renderer<B> {
+    #[inline]
     fn draw_chart<Message, C>(
         &self,
         chart: &C,
@@ -44,6 +46,7 @@ impl<B: Backend + backend::Text> ChartRenderer for Renderer<B> {
         )
     }
 
+    #[inline]
     fn on_event<Message, C: Chart<Message>>(
         &self,
         chart: &mut C,
